@@ -10,11 +10,20 @@
 
 #include <QIcon>
 
+static void resourceInit()
+{
+    // needs to be called outside of namespace
+    Q_INIT_RESOURCE(breeze_icons);
+}
+
 namespace BreezeIcons
 {
 
 void initIcons()
 {
+    // ensure the resource is there and loaded for static libs
+    resourceInit();
+
     // ensure we fallback to breeze, if no user fallback is set
     const QString fallbackTheme = QIcon::fallbackThemeName();
     if (fallbackTheme.isEmpty() || fallbackTheme == QLatin1String("hicolor")) {
